@@ -78,7 +78,7 @@ conboy_note_buffer_add_active_tag (ConboyNoteBuffer *self, GtkTextTag *tag)
 	g_return_if_fail(GTK_IS_TEXT_TAG(tag));
 
 	if (strncmp(tag->name, "depth", 5) == 0) {
-		g_printerr("WARNING: Trying to add depth tag. Not added\n", tag->name);
+		g_printerr("WARNING: Trying to add depth tag. Not added\n");
 		return;
 	}
 
